@@ -38,6 +38,7 @@
 #include <log-functions.h>
 #include <libosso.h>
 #include <osso-log.h>
+#include <locale.h>
 
 /* GTK includes */
 #include <glib.h>
@@ -137,6 +138,12 @@ static void
 cs_status_bar_init (CsStatusBar *self)
 {
     CsStatusBarPrivate *priv = CS_STATUS_BAR_GET_PRIVATE (self);
+    
+    /* Initialise the locale stuff */
+    setlocale ( LC_MESSAGES, "" );
+    bindtextdomain ( GETTEXT_PACKAGE, "/usr/share/locale" );
+    bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
+    textdomain ( GETTEXT_PACKAGE );
 
     USB_FLAG = TRUE;
     BT_FLAG = TRUE;
@@ -208,10 +215,7 @@ cs_set_icon (const gchar *name)
 
 static void
 cs_enviroment_menu_setup()
-{
-        openlog("Walter", LOG_NDELAY, LOG_USER);
-        syslog(LOG_ALERT, "cs_environment_menu_setup");
-               
+{       
         
         if (options->environments != NULL) {
             gtk_container_remove(GTK_CONTAINER(options->menu), options->environments );
@@ -221,7 +225,7 @@ cs_enviroment_menu_setup()
         GtkWidget *env_menu = gtk_menu_new();
         
         // Envs
-        options->environments = gtk_menu_item_new_with_label ("Environments");
+        options->environments = gtk_menu_item_new_with_label (_("Environments"));
         gtk_menu_item_set_submenu(GTK_MENU_ITEM(options->environments), env_menu);
         
         // Iterate to get all the available environments
@@ -271,7 +275,6 @@ cs_enviroment_menu_setup()
 
     
         gtk_widget_show_all(options->environments);
-        closelog(); 
 }
 
 static void
@@ -318,10 +321,10 @@ cs_environment_change(GtkWidget *widget, gpointer data)
         
         gchar message[80];
         if (error == FALSE) {
-            sprintf(message, "Environment %s applied successfully", clicked_env);
+            sprintf(message, _("Environment %s applied successfully"), clicked_env);
         }
         else {
-            sprintf(message, "Environment %s applied with errors", clicked_env);
+            sprintf(message, _("Environment %s applied with errors"), clicked_env);
         }
         
         g_debug("message: %s", message);
@@ -346,7 +349,7 @@ cs_menu_setup (void)
 
         /* USB file storage mode */
         options->menu_usb_storage =
-                gtk_check_menu_item_new_with_label ("USB file storage");
+                gtk_check_menu_item_new_with_label (_("USB file storage"));
         gtk_menu_shell_append (GTK_MENU_SHELL (options->menu),
                                 options->menu_usb_storage);
         g_signal_connect (G_OBJECT (options->menu_usb_storage), "activate",
@@ -354,7 +357,7 @@ cs_menu_setup (void)
 
         /* USB network device mode */
         options->menu_usb_netdev =
-                gtk_check_menu_item_new_with_label ("USB network");
+                gtk_check_menu_item_new_with_label (_("USB network"));
         gtk_menu_shell_append (GTK_MENU_SHELL (options->menu),
                                 options->menu_usb_netdev);
         g_signal_connect (G_OBJECT (options->menu_usb_netdev), "activate",
@@ -362,7 +365,7 @@ cs_menu_setup (void)
 
         /* Bluetooth network mode */
         options->menu_bt_netdev =
-                gtk_check_menu_item_new_with_label ("Bluetooth network");
+                gtk_check_menu_item_new_with_label (_("Bluetooth network"));
         gtk_menu_shell_append (GTK_MENU_SHELL (options->menu),
                                 options->menu_bt_netdev);
         g_signal_connect (G_OBJECT (options->menu_bt_netdev), "activate",
@@ -370,7 +373,7 @@ cs_menu_setup (void)
 
         /* WLAN Ad-Hoc network mode */
         options->menu_wlan_netdev =
-                gtk_check_menu_item_new_with_label ("Wlan adhoc network");
+                gtk_check_menu_item_new_with_label (_("Wlan adhoc network"));
         gtk_menu_shell_append (GTK_MENU_SHELL (options->menu),
                                 options->menu_wlan_netdev);
         g_signal_connect (G_OBJECT (options->menu_wlan_netdev), "activate",
@@ -488,7 +491,7 @@ cs_activate_usb_storage (GtkWidget *widget, gpointer data)
         options->usb_netdev = FALSE;
         options->usb_storage = TRUE;
 
-        hildon_banner_show_information(NULL, NULL, "USB file storage enabled");
+        hildon_banner_show_information(NULL, NULL, _("USB file storage enabled"));
     }
 }
 
@@ -512,7 +515,7 @@ cs_activate_usb_netdev (GtkWidget *widget, gpointer data)
         if (!nm_settings_start (settings)) {
 
             hildon_banner_show_information(NULL, NULL,
-                                            "Please, open PC-Connectivity manager and configure it.");
+                                            _("Please, open PC-Connectivity manager and configure it."));
             return;
         }
 
@@ -533,7 +536,7 @@ cs_activate_usb_netdev (GtkWidget *widget, gpointer data)
         options->usb_netdev = TRUE;
         options->usb_storage = FALSE;
 
-        hildon_banner_show_information(NULL, NULL, "USB network enabled");
+        hildon_banner_show_information(NULL, NULL, _("USB network enabled"));
     }
 }
 
@@ -557,7 +560,7 @@ cs_activate_bt_netdev (GtkWidget *widget, gpointer data)
         if (!nm_settings_start (settings)) {
 
             hildon_banner_show_information(NULL, NULL,
-                                            "Please, open PC-Connectivity manager and configure it.");
+                                            _("Please, open PC-Connectivity manager and configure it."));
             return;
         }
 
@@ -569,23 +572,23 @@ cs_activate_bt_netdev (GtkWidget *widget, gpointer data)
         if (strcmp (btaddr, NM_BT_DEFAULT_MAC) == 0) {
 
             hildon_banner_show_information (NULL, NULL,
-                                             "Please, open network manager and\nconfigure bluetooth interface!");
+                                             _("Please, open network manager and\nconfigure bluetooth interface!"));
             return;
         } else if (nm_bt_utils_check_pand (options->bt_utils, btaddr) == NULL) {
 
             hildon_banner_show_information (NULL, NULL,
-                                            "Unable to connect. Check if PAND is running on host!");
+                                            _("Unable to connect. Check if PAND is running on host!"));
             return;
         }
 
         if (!nm_bt_utils_connect (options->bt_utils, btaddr, gw)) {
 
             hildon_banner_show_information (NULL, NULL,
-                                            "Could not connect to PC");
+                                            _("Could not connect to PC"));
             return;
         }
 
-        hildon_banner_show_information(NULL, NULL, "Bluetooth network enabled");
+        hildon_banner_show_information(NULL, NULL, _("Bluetooth network enabled"));
 
         BT_FLAG = !BT_FLAG;
         g_object_set_property (G_OBJECT (options->menu_bt_netdev),
@@ -597,7 +600,7 @@ cs_activate_bt_netdev (GtkWidget *widget, gpointer data)
         nm_bt_utils_remove_connection (options->bt_utils);
 
         hildon_banner_show_information(NULL, NULL,
-                                        "Bluetooth network disabled");
+                                        _("Bluetooth network disabled"));
 
         BT_FLAG = !BT_FLAG;
         g_object_set_property (G_OBJECT (options->menu_bt_netdev),
@@ -633,7 +636,7 @@ cs_activate_wlan_netdev (GtkWidget *widget, gpointer data)
         WLAN_FLAG = !WLAN_FLAG;
         options->wlan_netdev = TRUE;
 
-        hildon_banner_show_information(NULL, NULL, "WLAN adhoc network enabled");
+        hildon_banner_show_information(NULL, NULL, _("WLAN adhoc network enabled"));
     } else if (options->wlan_netdev && WLAN_FLAG) {
 
         // FIXME: reconnect to previous wlan network
@@ -644,6 +647,6 @@ cs_activate_wlan_netdev (GtkWidget *widget, gpointer data)
         WLAN_FLAG = !WLAN_FLAG;
         options->wlan_netdev = FALSE;
 
-        hildon_banner_show_information(NULL, NULL, "WLAN adhoc network disabled");
+        hildon_banner_show_information(NULL, NULL, _("WLAN adhoc network disabled"));
     }
 }
